"use server";

import { requestGetFetch, requestPostFetch } from "@/utils/fetch";
import { Session } from "next-auth";
import { getServerSession } from "next-auth";
import { nextauthOptions } from "../nextauth-options";
import { SearchParams } from "@/types/searchParams";

export async function getAssignmentList(searchParams?: SearchParams) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;

    // Dynamically build the query string from searchParams
    const paramsArray = searchParams && Object.entries(searchParams);
    const queryString = paramsArray
      ? paramsArray
        .map(([key, value]) =>
          Array.isArray(value)
            ? `${key}=${value.join(",")}` // Use .join(",") without encoding commas
            : `${key}=${String(value)}` // Encode only non-array values
        )
        .join("&")
      : "";

    const path = 'v1/assignments' + `${queryString ? `?${queryString}` : ''}`;


    const response = await requestGetFetch({
      path: path.toString(),
      options: {
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
      },
    });
    return response;
  } catch (error) {
    if (error) {

    }
    throw error;
  }
}

export async function deleteAssignment(id: number | string) {
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user?.token;
    const path = "v1/assignments/" + id;
    const response = await requestGetFetch({
      path,
      options: {
        method: "Delete",
        headers: {
          Authorization: `Bearer ${token}`,
          "Content-Type": "application/json",
          Accept: "application/json",
        },
        cache: 'no-store',
      },
    });
    return response;
  } catch (error) {
    if (error) {

    }
    throw error;
  }
}

export async function transferAssignments(payload: {
  due_date?: string;
  from_user_id: number;
  to_user_id: number;
  assignment_ids: number[];
}) {
  console.log(payload);
  try {
    const session: Session = await getServerSession(nextauthOptions);
    const token = session?.user.token;
    
    const response = await requestPostFetch({
      path: `v1/assignments/transfer`,
      data: payload,
      token: token,
    });
    
    return response;
  } catch (error: any) {
    throw new Error(error.message);
  }
}